summaryrefslogtreecommitdiffstats
path: root/twin/clients/web
diff options
context:
space:
mode:
Diffstat (limited to 'twin/clients/web')
-rw-r--r--twin/clients/web/Web.cpp32
-rw-r--r--twin/clients/web/Web.h2
-rw-r--r--twin/clients/web/WebButton.cpp26
-rw-r--r--twin/clients/web/WebButton.h4
4 files changed, 32 insertions, 32 deletions
diff --git a/twin/clients/web/Web.h b/twin/clients/web/Web.h
index ec1b08dc5..c2c18b0bd 100644
--- a/twin/clients/web/Web.h
+++ b/twin/clients/web/Web.h
@@ -62,7 +62,7 @@ namespace Web
int titleHeight_, borderSize_;
- bool shape_;
+ bool tqshape_;
TQBitmap _buttonBitmap(ButtonType t) const;
};
diff --git a/twin/clients/web/WebButton.cpp b/twin/clients/web/WebButton.cpp
index 785abe699..bf1f54af4 100644
--- a/twin/clients/web/WebButton.cpp
+++ b/twin/clients/web/WebButton.cpp
@@ -69,10 +69,10 @@ namespace Web {
0xff, 0x81, 0x81, 0xff, 0x81, 0xff, 0x81, 0xff
};
-WebButton::WebButton(ButtonType type, WebClient *parent, const char *name, bool shape)
+WebButton::WebButton(ButtonType type, WebClient *parent, const char *name, bool tqshape)
: KCommonDecorationButton (type, parent, name),
mouseOver_ (false),
- shape_ (shape),
+ tqshape_ (tqshape),
deco_ (parent)
{
setBackgroundMode(NoBackground);
@@ -127,7 +127,7 @@ void WebButton::reset(unsigned long changed)
WebButton::enterEvent(TQEvent * e)
{
mouseOver_ = true;
- repaint();
+ tqrepaint();
TQButton::enterEvent(e);
}
@@ -135,7 +135,7 @@ WebButton::enterEvent(TQEvent * e)
WebButton::leaveEvent(TQEvent * e)
{
mouseOver_ = false;
- repaint();
+ tqrepaint();
TQButton::leaveEvent(e);
}
@@ -145,17 +145,17 @@ WebButton::drawButton(TQPainter *p)
TQPen highlightPen;
if (isDown() )
- highlightPen = TQPen(colorGroup().light());
+ highlightPen = TQPen(tqcolorGroup().light());
else
{
if (mouseOver_)
- highlightPen = TQPen(colorGroup().highlight());
+ highlightPen = TQPen(tqcolorGroup().highlight());
else
highlightPen = TQPen(NoPen);
}
- p->fillRect(rect(), colorGroup().background());
+ p->fillRect(rect(), tqcolorGroup().background());
Position position_;
if (0 == mapToParent(rect().topLeft() ).x() )
@@ -174,7 +174,7 @@ WebButton::drawButton(TQPainter *p)
p->drawLine(0, 0, width(), 0);
p->drawLine(0, 1, 0, height() - 1);
- if (shape_)
+ if (tqshape_)
{
p->drawPoint(3, 1);
p->drawPoint(4, 1);
@@ -187,11 +187,11 @@ WebButton::drawButton(TQPainter *p)
p->setBrush(NoBrush);
p->setPen(highlightPen);
- if (shape_)
+ if (tqshape_)
p->setClipRegion(TQRegion(rect()) - TQRect(0, 0, 6, 6));
p->drawRect(2, 2, width() - 4, height() - 4);
- if (shape_)
+ if (tqshape_)
{
p->setClipRect(rect());
p->drawPoint(4, 3);
@@ -210,7 +210,7 @@ WebButton::drawButton(TQPainter *p)
p->setPen(Qt::black);
p->drawLine(0, 0, width(), 0);
p->drawLine(width() - 1, 1, width() - 1, height() - 1);
- if (shape_)
+ if (tqshape_)
{
p->drawPoint(width() - 5, 1);
p->drawPoint(width() - 4, 1);
@@ -223,11 +223,11 @@ WebButton::drawButton(TQPainter *p)
p->setBrush(NoBrush);
p->setPen(highlightPen);
- if (shape_)
+ if (tqshape_)
p->setClipRegion(TQRegion(rect()) - TQRect(width() - 6, 0, 6, 6));
p->drawRect(2, 2, width() - 4, height() - 4);
- if (shape_)
+ if (tqshape_)
{
p->setClipRect(rect());
p->drawPoint(width() - 5, 3);
diff --git a/twin/clients/web/WebButton.h b/twin/clients/web/WebButton.h
index d86db6cc6..108aa2a52 100644
--- a/twin/clients/web/WebButton.h
+++ b/twin/clients/web/WebButton.h
@@ -41,7 +41,7 @@ namespace Web
Left, Mid, Right
};
- WebButton(ButtonType type, WebClient *parent, const char *name, bool shape);
+ WebButton(ButtonType type, WebClient *parent, const char *name, bool tqshape);
virtual ~WebButton();
@@ -59,7 +59,7 @@ namespace Web
bool mouseOver_;
- bool shape_;
+ bool tqshape_;
WebClient* deco_;
};
}
diff --git a/twin/clients/web/Web.cpp b/twin/clients/web/Web.cpp
index f799e1b8b..793b406af 100644
--- a/twin/clients/web/Web.cpp
+++ b/twin/clients/web/Web.cpp
@@ -120,31 +120,31 @@ KCommonDecorationButton *WebClient::createButton(ButtonType type)
{
switch (type) {
case MenuButton:
- return new WebButton(MenuButton, this, "menu", shape_);
+ return new WebButton(MenuButton, this, "menu", tqshape_);
case OnAllDesktopsButton:
- return new WebButton(OnAllDesktopsButton, this, "on_all_desktops", shape_);
+ return new WebButton(OnAllDesktopsButton, this, "on_all_desktops", tqshape_);
case HelpButton:
- return new WebButton(HelpButton, this, "help", shape_);
+ return new WebButton(HelpButton, this, "help", tqshape_);
case MinButton:
- return new WebButton(MinButton, this, "minimize", shape_);
+ return new WebButton(MinButton, this, "minimize", tqshape_);
case MaxButton:
- return new WebButton(MaxButton, this, "maximize", shape_);
+ return new WebButton(MaxButton, this, "maximize", tqshape_);
case CloseButton:
- return new WebButton(CloseButton, this, "close", shape_);
+ return new WebButton(CloseButton, this, "close", tqshape_);
case AboveButton:
- return new WebButton(AboveButton, this, "above", shape_);
+ return new WebButton(AboveButton, this, "above", tqshape_);
case BelowButton:
- return new WebButton(BelowButton, this, "below", shape_);
+ return new WebButton(BelowButton, this, "below", tqshape_);
case ShadeButton:
- return new WebButton(ShadeButton, this, "shade", shape_);
+ return new WebButton(ShadeButton, this, "shade", tqshape_);
default:
return 0;
@@ -185,7 +185,7 @@ WebClient::init()
KConfig c("twinwebrc");
c.setGroup("General");
- shape_ = c.readBoolEntry("Shape", true);
+ tqshape_ = c.readBoolEntry("Shape", true);
KCommonDecoration::init();
}
@@ -195,8 +195,8 @@ WebClient::reset( unsigned long changed )
{
if (changed & SettingColors)
{
- // repaint the whole thing
- widget()->repaint(false);
+ // tqrepaint the whole thing
+ widget()->tqrepaint(false);
} else if (changed & SettingFont) {
// font has changed -- update title height
// title height
@@ -206,7 +206,7 @@ WebClient::reset( unsigned long changed )
if (0 != titleHeight_ % 2)
titleHeight_ += 1;
- widget()->repaint(false);
+ widget()->tqrepaint(false);
}
KCommonDecoration::reset(changed);
@@ -231,7 +231,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
TQPainter p(widget());
p.setPen(Qt::black);
- p.setBrush(options()->colorGroup(ColorFrame, isActive()).background());
+ p.setBrush(options()->tqcolorGroup(ColorFrame, isActive()).background());
p.setClipRegion(pe->region() - titleRect);
@@ -241,7 +241,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
p.fillRect(titleRect, options()->color(ColorTitleBar, isActive()));
- if (shape_)
+ if (tqshape_)
{
int r(width());
int b(height());
@@ -288,7 +288,7 @@ WebClient::paintEvent(TQPaintEvent * pe)
void WebClient::updateWindowShape()
{
- if (!shape_)
+ if (!tqshape_)
return;
TQRegion mask(0, 0, width(), height());